@@ -1,4 +1,11 @@
 from .classification.alexnet import AlexNet, alexnet
+from .classification.convnext import (
+    ConvNeXt,
+    convnext_base,
+    convnext_large,
+    convnext_small,
+    convnext_tiny,
+)
 from .classification.densenet import (
     DenseNet,
     densenet121,
@@ -6,6 +13,20 @@ from .classification.densenet import (
     densenet169,
     densenet201,
 )
+from .classification.efficientnet import (
+    EfficientNet,
+    efficientnet_b0,
+    efficientnet_b1,
+    efficientnet_b2,
+    efficientnet_b3,
+    efficientnet_b4,
+    efficientnet_b5,
+    efficientnet_b6,
+    efficientnet_b7,
+    efficientnet_v2_l,
+    efficientnet_v2_m,
+    efficientnet_v2_s,
+)
 from .classification.googlenet import GoogLeNet, googlenet
 from .classification.mobilenetv2 import mobilenet_v2, MobileNetV2
 from .classification.mobilenetv3 import (
@@ -25,6 +46,13 @@ from .classification.resnet import (
     wide_resnet50_2,
     wide_resnet101_2,
 )
+from .classification.shufflenetv2 import (
+    shufflenet_v2_x0_5,
+    shufflenet_v2_x1_0,
+    shufflenet_v2_x1_5,
+    shufflenet_v2_x2_0,
+    ShuffleNetV2,
+)
 from .classification.squeezenet import SqueezeNet, squeezenet1_0, squeezenet1_1
 from .classification.vgg import (
     VGG,
