@@ -1,10 +1,13 @@
 from . import (
     alexnet,
+    convnext,
     densenet,
+    efficientnet,
     googlenet,
     mobilenetv2,
     mobilenetv3,
     resnet,
+    shufflenetv2,
     squeezenet,
     vgg,
     vit,
