@@ -1,3 +1,4 @@
+import warnings
 from typing import Any, Callable, List, Optional, Union
 
 import equinox as eqx
@@ -8,6 +9,8 @@ import jax.numpy as jnp
 import jax.random as jrandom
 from equinox.custom_types import Array
 
+from ...utils import load_torch_weights, MODEL_URLS
+
 
 class GoogLeNet(eqx.Module):
     """A simple port of `torchvision.models.GoogLeNet`"""
@@ -38,7 +41,7 @@ class GoogLeNet(eqx.Module):
     def __init__(
         self,
         num_classes: int = 1000,
-        aux_logits: bool = True,
+        aux_logits: bool = False,
         blocks: Optional[List[Callable[..., eqx.Module]]] = None,
         dropout: float = 0.2,
         dropout_aux: float = 0.7,
@@ -50,7 +53,7 @@ class GoogLeNet(eqx.Module):
 
         - `num_classes`: Number of classes in the classification task.
                         Also controls the final output shape `(num_classes,)`. Defaults to `1000`
-        - `aux_logits`: If `True`, two auxiliary branches are added to the network. Defaults to `True`
+        - `aux_logits`: If `True`, two auxiliary branches are added to the network. Defaults to `False`
         - `blocks`: Blocks for constructing the network
         - `dropout`: Dropout applied on the `main` branch. Defaults to `0.2`
         - `dropout_aux`: Dropout applied on the `aux` branches. Defaults to `0.7`
@@ -307,9 +310,26 @@ class BasicConv2d(eqx.Module):
         return jnn.relu(x)
 
 
-def googlenet(**kwargs: Any) -> GoogLeNet:
+def googlenet(pretrained=False, **kwargs: Any) -> GoogLeNet:
     r"""GoogLeNet (Inception v1) model architecture from
     `"Going Deeper with Convolutions" <http://arxiv.org/abs/1409.4842>`_.
     The required minimum input size of the model is 15x15.
+
+    **Arguments:**
+
+    - `pretrained`: If `True`, the weights are loaded from `PyTorch` saved checkpoint.
+
     """
-    return GoogLeNet(**kwargs)
+    if pretrained:
+        use_aux = kwargs.get("aux_logits", False)
+        model = GoogLeNet(aux_logits=True, **kwargs)
+        model = load_torch_weights(model, url=MODEL_URLS["googlenet"])
+        if not use_aux:
+            model = eqx.tree_at(lambda m: m.aux_logits, model, replace=(False))
+        else:
+            warnings.warn(
+                "Loaded pretrained weights for GoogLeNet. But, aux-branch weights are un-trained."
+            )
+    else:
+        model = GoogLeNet(**kwargs)
+    return model
