@@ -18,10 +18,25 @@ _TEMP_DIR = "/tmp/.eqx"
 _Url = NewType("_Url", str)
 MODEL_URLS = {
     "alexnet": "https://download.pytorch.org/models/alexnet-owt-7be5be79.pth",
+    "convnext_tiny": "https://download.pytorch.org/models/convnext_tiny-983f1562.pth",
+    "convnext_small": "https://download.pytorch.org/models/convnext_small-0c510722.pth",
+    "convnext_base": "https://download.pytorch.org/models/convnext_base-6075fbad.pth",
+    "convnext_large": "https://download.pytorch.org/models/convnext_large-ea097f82.pth",
     "densenet121": "https://download.pytorch.org/models/densenet121-a639ec97.pth",
     "densenet169": "https://download.pytorch.org/models/densenet169-b2777c0a.pth",
     "densenet201": "https://download.pytorch.org/models/densenet201-c1103571.pth",
     "densenet161": "https://download.pytorch.org/models/densenet161-8d451a50.pth",
+    "efficientnet_b0": "https://download.pytorch.org/models/efficientnet_b0_rwightman-3dd342df.pth",
+    "efficientnet_b1": "https://download.pytorch.org/models/efficientnet_b1_rwightman-533bc792.pth",
+    "efficientnet_b2": "https://download.pytorch.org/models/efficientnet_b2_rwightman-bcdf34b7.pth",
+    "efficientnet_b3": "https://download.pytorch.org/models/efficientnet_b3_rwightman-cf984f9c.pth",
+    "efficientnet_b4": "https://download.pytorch.org/models/efficientnet_b4_rwightman-7eb33cd5.pth",
+    "efficientnet_b5": "https://download.pytorch.org/models/efficientnet_b5_lukemelas-b6417697.pth",
+    "efficientnet_b6": "https://download.pytorch.org/models/efficientnet_b6_lukemelas-c76e70fd.pth",
+    "efficientnet_b7": "https://download.pytorch.org/models/efficientnet_b7_lukemelas-dcc49843.pth",
+    "efficientnet_v2_s": "https://download.pytorch.org/models/efficientnet_v2_s-dd5fe13b.pth",
+    "efficientnet_v2_m": "https://download.pytorch.org/models/efficientnet_v2_m-dc08266a.pth",
+    "efficientnet_v2_l": "https://download.pytorch.org/models/efficientnet_v2_l-59c71312.pth",
     "googlenet": "https://download.pytorch.org/models/googlenet-1378be20.pth",
     "mobilenet_v2": "https://download.pytorch.org/models/mobilenet_v2-b0353104.pth",
     "mobilenet_v3_large": "https://download.pytorch.org/models/mobilenet_v3_large-8738ca79.pth",
@@ -33,8 +48,20 @@ MODEL_URLS = {
     "resnet152": "https://download.pytorch.org/models/resnet152-b121ed2d.pth",
     "resnext50_32x4d": "https://download.pytorch.org/models/resnext50_32x4d-7cdf4587.pth",
     "resnext101_32x8d": "https://download.pytorch.org/models/resnext101_32x8d-8ba56ff5.pth",
+    "shufflenetv2_x0.5": "https://download.pytorch.org/models/shufflenetv2_x0.5-f707e7126e.pth",
+    "shufflenetv2_x1.0": "https://download.pytorch.org/models/shufflenetv2_x1-5666bf0f80.pth",
+    "shufflenetv2_x1.5": None,
+    "shufflenetv2_x2.0": None,
     "squeezenet1_0": "https://download.pytorch.org/models/squeezenet1_0-b66bff10.pth",
     "squeezenet1_1": "https://download.pytorch.org/models/squeezenet1_1-b8a52dc0.pth",
+    "vit_small_patch16_224_dino": "https://dl.fbaipublicfiles.com/dino/"
+    "dino_deitsmall16_pretrain/dino_deitsmall16_pretrain.pth",
+    "vit_small_patch8_224_dino": "https://dl.fbaipublicfiles.com/dino/"
+    "dino_deitsmall8_pretrain/dino_deitsmall8_pretrain.pth",
+    "vit_base_patch16_224_dino": "https://dl.fbaipublicfiles.com/dino/"
+    "dino_vitbase16_pretrain/dino_vitbase16_pretrain.pth",
+    "vit_base_patch8_224_dino": "https://dl.fbaipublicfiles.com/dino/"
+    "dino_vitbase8_pretrain/dino_vitbase8_pretrain.pth",
     "vgg11": "https://download.pytorch.org/models/vgg11-8a719046.pth",
     "vgg13": "https://download.pytorch.org/models/vgg13-19584684.pth",
     "vgg16": "https://download.pytorch.org/models/vgg16-397923af.pth",
@@ -96,9 +123,19 @@ def load_torch_weights(
         [
             jnp.asarray(weight.detach().numpy())
             for name, weight in weights.items()
-            if "bn.running" not in name and "bn.num" not in name
+            if "running" not in name and "num_batches" not in name
         ]
     )
+
+    bn_s = []
+    for name, weight in weights.items():
+        if "running_mean" in name:
+            bn_s.append(False)
+            bn_s.append(jnp.asarray(weight.detach().numpy()))
+        elif "running_var" in name:
+            bn_s.append(jnp.asarray(weight.detach().numpy()))
+    bn_iterator = iter(bn_s)
+
     leaves, tree_def = jtu.tree_flatten(model)
 
     new_leaves = []
@@ -111,7 +148,25 @@ def load_torch_weights(
         else:
             new_leaves.append(leaf)
 
-    return jtu.tree_unflatten(tree_def, new_leaves)
+    model = jtu.tree_unflatten(tree_def, new_leaves)
+
+    def set_experimental(iter_bn, x):
+        def set_values(y):
+            if isinstance(y, eqx.experimental.StateIndex):
+                current_val = next(iter_bn)
+                if isinstance(current_val, bool):
+                    eqx.experimental.set_state(y, jnp.asarray(False))
+                else:
+                    running_mean, running_var = current_val, next(iter_bn)
+                    eqx.experimental.set_state(y, (running_mean, running_var))
+            return y
+
+        return jtu.tree_map(
+            set_values, x, is_leaf=lambda _: isinstance(_, eqx.experimental.StateIndex)
+        )
+
+    model = jtu.tree_map(set_experimental, bn_iterator, model)
+    return model
 
 
 def _make_divisible(v: float, divisor: int, min_value: Optional[int] = None) -> int:
